==> nextcloud-30.0.4.tgz: nextcloud/apps/notifications/l10n/ga.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Ba mhaith linn leanúint ar aghaidh ag tairiscint ár seirbhís fógra brú a chur ar fáil saor in aisce, ach tá líon mór úsáideoirí ró-ualach ár mbonneagar. Ar an ábhar sin ní mór dúinn teorainn ráta a úsáid le húsáid fógraí brú. Má theastaíonn an ghné seo uait, smaoinigh ar Nextcloud Enterprise a úsáid.",
    "User not found" : "Úsáideoir gan aimsiú",
    "The device does not seem to be supported" : "Is cosúil nach dtacaítear leis an bhfeiste",
    "An unexpected error occurred, ask your administration to check the logs." : "Tharla earráid gan choinne, iarr ar do riarachán na logaí a sheiceáil.",
    "Hello %s" : "Dia duit %s",
    "Hello %s," : "Dia duit %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["fógraí nua le haghaidh %s","%n fógraí nua le haghaidh %s","%n fógraí nua le haghaidh %s","%n fógraí nua le haghaidh%s","%n fógraí nua le haghaidh%s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Tá fógra nua agat le haghaidh%s","Tá %n fógra nua agat le haghaidh %s  ","Tá %n fógra nua agat le haghaidh %s","Tá %n fógra nua agat le haghaidh %s","Tá %n fógra nua agat le haghaidh %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Is féidir leat minicíocht na ríomhphost seo a athrú nó iad a dhíchumasú sna <a href=\"%s\">socruithe</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Is féidir leat minicíocht na ríomhphost seo a athrú nó iad a dhíchumasú sna socruithe: %s",
    "Admin notifications" : "Fógraí riaracháin",
    "Notifications" : "Fógraí",
    "Push notifications - Fair use policy" : "Fógraí brú - Beartas um úsáid chóir",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Déanann Nextcloud GmbH urraíocht ar gheata fógra brú saor in aisce d’úsáideoirí príobháideacha. Chun seirbhís mhaith a chinntiú, cuireann an tairseach teorainn le líon na bhfógraí brú in aghaidh an fhreastalaí agus baineadh amach an teorainn don fhreastalaí seo. I gcás úsáideoirí fiontair, tá geata níos Inscálaithe ar fáil.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Soláthraíonn an aip seo inneall agus tosaigh don API fógra atá ar fáil in Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Soláthraíonn an aip seo inneall agus tosaigh don API fógra atá ar fáil in Nextcloud.\n\t\t Úsáideann aipeanna eile an API chun úsáideoirí san Chomhéadain Gréasáin a chur ar an eolas agus chun cliaint a shioncronú faoi rudaí éagsúla. Seo a leanas roinnt samplaí:\n\n📬 Comhroinnt chónaidhme: Fuair tú cianroinnt nua\n\n📑 Nótaí tráchta: Luaigh úsáideoir eile tú i dtrácht ar chomhad\n\n🚢 Fógra nuashonraithe: Nuashonrú ar fáil d'aip nó nextcloud féin\n\n📣 Ionad fógartha: Chuir riarthóir fógra suas",
    "Failed to perform action" : "Theip ar an ngníomh a dhéanamh",
    "Dismiss" : "Díbhe",
    "Contact Nextcloud GmbH" : "Déan teagmháil le Nextcloud GmbH",
    "seconds ago" : "soicind ó shin",
    "Failed to dismiss notification" : "Theip ar an bhfógra a dhíbhe",
    "in {path}" : "in {path}",
    "Dismiss all notifications" : "Ruaig gach fógra",
    "Requesting browser permissions to show notifications" : "Ag iarraidh ceadanna brabhsálaí chun fógraí a thaispeáint",
    "Push notifications might be unreliable" : "Seans go mbeidh fógraí brúigh neamhiontaofa",
    "No notifications" : "Gan fógraí",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Déanann Nextcloud GmbH urraíocht ar gheata fógra brú saor in aisce d’úsáideoirí príobháideacha. Chun seirbhís mhaith a chinntiú, cuireann an tairseach teorainn le líon na bhfógraí brú in aghaidh an fhreastalaí. I gcás úsáideoirí fiontair, tá geata níos Inscálaithe ar fáil. Déan teagmháil le Nextcloud GmbH le haghaidh tuilleadh eolais.",
    "Failed to dismiss all notifications" : "Theip ar dhíbhe gach fógra",
    "Notifications defaults" : "Réamhshocruithe fógraí",
    "Configure the default notification settings for new users" : "Cumraigh na socruithe fógra réamhshocraithe d'úsáideoirí nua",
    "Send email reminders about unhandled notifications after:" : "Seol meabhrúcháin ríomhphoist maidir le fógraí nár láimhseáiltear tar éis:",
    "Play sound when a new notification arrives" : "Seinn an fhuaim nuair a thagann fógra nua",
    "Play sound when a call started (requires Nextcloud Talk)" : "Seinn an fhuaim nuair a thosaigh an glao (tá Nextcloud Talk ag teastáil)",
    "Never" : "Riamh",
    "1 hour" : "1 uair",
    "3 hours" : "3 uair an chloig",
    "1 day" : "1 lá",
    "1 week" : "1 seachtain",
    "Your settings have been updated." : "Nuashonraíodh do shocruithe.",
    "An error occurred while updating your settings." : "Tharla earráid agus do shocruithe á nuashonrú.",
    "You need to set up your email address before you can receive notification emails." : "Ní mór duit do sheoladh ríomhphoist a shocrú sula mbeidh tú in ann ríomhphoist fógra a fháil.",
    "Also repeat sound on a secondary speaker" : "Déan fuaim arís ar chainteoir tánaisteach freisin",
    "Selection of the speaker device is currently not supported by Safari" : "Ní thacaíonn Safari le roghnú gléas an chainteora faoi láthair",
    "Select a device" : "Roghnaigh gléas",
    "None" : "aon cheann"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/notifications/l10n/ga.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Ba mhaith linn leanúint ar aghaidh ag tairiscint ár seirbhís fógra brú a chur ar fáil saor in aisce, ach tá líon mór úsáideoirí ró-ualach ár mbonneagar. Ar an ábhar sin ní mór dúinn teorainn ráta a úsáid le húsáid fógraí brú. Má theastaíonn an ghné seo uait, smaoinigh ar Nextcloud Enterprise a úsáid.",
    "User not found" : "Úsáideoir gan aimsiú",
    "An unexpected error occurred, ask your administration to check the logs." : "Tharla earráid gan choinne, iarr ar do riarachán na logaí a sheiceáil.",
    "Hello %s" : "Dia duit %s",
    "Hello %s," : "Dia duit %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["fógraí nua le haghaidh %s","%n fógraí nua le haghaidh %s","%n fógraí nua le haghaidh %s","%n fógraí nua le haghaidh%s","%n fógraí nua le haghaidh%s"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Tá fógra nua agat le haghaidh%s","Tá %n fógra nua agat le haghaidh %s  ","Tá %n fógra nua agat le haghaidh %s","Tá %n fógra nua agat le haghaidh %s","Tá %n fógra nua agat le haghaidh %s"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Is féidir leat minicíocht na ríomhphost seo a athrú nó iad a dhíchumasú sna <a href=\"%s\">socruithe</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Is féidir leat minicíocht na ríomhphost seo a athrú nó iad a dhíchumasú sna socruithe: %s",
    "Admin notifications" : "Fógraí riaracháin",
    "Notifications" : "Fógraí",
    "Push notifications - Fair use policy" : "Fógraí brú - Beartas um úsáid chóir",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Déanann Nextcloud GmbH urraíocht ar gheata fógra brú saor in aisce d’úsáideoirí príobháideacha. Chun seirbhís mhaith a chinntiú, cuireann an tairseach teorainn le líon na bhfógraí brú in aghaidh an fhreastalaí agus baineadh amach an teorainn don fhreastalaí seo. I gcás úsáideoirí fiontair, tá geata níos Inscálaithe ar fáil.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "Soláthraíonn an aip seo inneall agus tosaigh don API fógra atá ar fáil in Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "Soláthraíonn an aip seo inneall agus tosaigh don API fógra atá ar fáil in Nextcloud.\n\t\t Úsáideann aipeanna eile an API chun úsáideoirí san Chomhéadain Gréasáin a chur ar an eolas agus chun cliaint a shioncronú faoi rudaí éagsúla. Seo a leanas roinnt samplaí:\n\n📬 Comhroinnt chónaidhme: Fuair tú cianroinnt nua\n\n📑 Nótaí tráchta: Luaigh úsáideoir eile tú i dtrácht ar chomhad\n\n🚢 Fógra nuashonraithe: Nuashonrú ar fáil d'aip nó nextcloud féin\n\n📣 Ionad fógartha: Chuir riarthóir fógra suas",
    "Failed to perform action" : "Theip ar an ngníomh a dhéanamh",
    "seconds ago" : "soicind ó shin",
    "Failed to dismiss notification" : "Theip ar an bhfógra a dhíbhe",
    "Dismiss" : "Díbhe",
    "Contact Nextcloud GmbH" : "Déan teagmháil le Nextcloud GmbH",
    "in {path}" : "in {path}",
    "Requesting browser permissions to show notifications" : "Ag iarraidh ceadanna brabhsálaí chun fógraí a thaispeáint",
    "Push notifications might be unreliable" : "Seans go mbeidh fógraí brúigh neamhiontaofa",
    "No notifications" : "Gan fógraí",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Déanann Nextcloud GmbH urraíocht ar gheata fógra brú saor in aisce d’úsáideoirí príobháideacha. Chun seirbhís mhaith a chinntiú, cuireann an tairseach teorainn le líon na bhfógraí brú in aghaidh an fhreastalaí. I gcás úsáideoirí fiontair, tá geata níos Inscálaithe ar fáil. Déan teagmháil le Nextcloud GmbH le haghaidh tuilleadh eolais.",
    "Failed to dismiss all notifications" : "Theip ar dhíbhe gach fógra",
    "Dismiss all notifications" : "Ruaig gach fógra",
    "Never" : "Riamh",
    "1 hour" : "1 uair",
    "3 hours" : "3 uair an chloig",
    "1 day" : "1 lá",
    "1 week" : "1 seachtain",
    "Your settings have been updated." : "Nuashonraíodh do shocruithe.",
    "An error occurred while updating your settings." : "Tharla earráid agus do shocruithe á nuashonrú.",
    "Notifications defaults" : "Réamhshocruithe fógraí",
    "Configure the default notification settings for new users" : "Cumraigh na socruithe fógra réamhshocraithe d'úsáideoirí nua",
    "Send email reminders about unhandled notifications after:" : "Seol meabhrúcháin ríomhphoist maidir le fógraí nár láimhseáiltear tar éis:",
    "Play sound when a new notification arrives" : "Seinn an fhuaim nuair a thagann fógra nua",
    "Play sound when a call started (requires Nextcloud Talk)" : "Seinn an fhuaim nuair a thosaigh an glao (tá Nextcloud Talk ag teastáil)",
    "None" : "aon cheann",
    "You need to set up your email address before you can receive notification emails." : "Ní mór duit do sheoladh ríomhphoist a shocrú sula mbeidh tú in ann ríomhphoist fógra a fháil.",
    "Also repeat sound on a secondary speaker" : "Déan fuaim arís ar chainteoir tánaisteach freisin",
    "Selection of the speaker device is currently not supported by Safari" : "Ní thacaíonn Safari le roghnú gléas an chainteora faoi láthair",
    "Select a device" : "Roghnaigh gléas"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
